==> heteroscalapack-1.0.1-BETA.tar.gz: heteroscalapack-1.0.1-BETA/HETEROMPI/include/hmpi_internal_funcs.h <==

/*************************************************************************
*                                                                       *
*                 HMPI Programming Environment                          *
*                 ============================                          *
*                                                                       *
*  Copyright (c) 2002          Department of Computer Science,          *
*                              University College Dublin.               *
*                                                                       *
*  All rights reserved. We assume no responsibility for the use         *
*  or reliability of our software.                                      *
*                                                                       *
*************************************************************************/

   /************************************************/
   /* hmpi - Internal helper functions of the      */
   /*        the HeteroMPI library                 */
   /*                                              */
   /* Revision history                             */
   /* 04-10-2007  --      Adding optimal algorithm */
   /*                     parameters to the Network*/
   /************************************************/

   #ifndef __HMPI_INTERNAL_FUNCS_HH
   #define __HMPI_INTERNAL_FUNCS_HH

   #define  HMPI_MAX_INITIAL_PROC_ARRMTS   16
   #define  HMPI_MSG_TAG                   0xff

   /*-----------------------------------------------------*/

   int
   HMPI_Get_process_arrangements_recursively_i
   (
       int d,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int gsize,
       int numcoord,
       int *coord,
       int **parr,
       int *nparr,
       int *max_nparr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Get_process_arrangements_i
   (
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int **parr,
       int *nparr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Test_size_i
   (
       int gsize,
       int numcoord,
       const int *dim
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Evaluate_model_recursively_i
   (
       int d,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int gsize,
       int numcoord,
       double *mintime,
       int *dim,
       int *optimal_dim,
       int **optimal_speeds
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Group_auto_create_i
   (
       HMPI_Group* gid,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Test_one_proc_i
   (
       int numcoord,
       const int *dim
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Group_pauto_create_i
   (
       HMPI_Group* gid,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count
   );

   /*-----------------------------------------------------*/

   int HMPI_Reorder_arrangements_i(
       int numcoord,
       int nparr,
       int *parr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Copy_arrangements_i
   (
       int numcoord,
       int *dim1,
       int *dim2
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Get_product_i
   (
       int numcoord,
       const int *dim
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Execute_heuristic_i
   (
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int numcoord,
       int *coord,
       int **parr,
       int *nparr,
       int *max_nparr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Get_process_arrangements_d_loop_i
   (
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int gsize,
       int numcoord,
       int *coord,
       int **parr,
       int *nparr,
       int *max_nparr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Get_process_arrangements_d_i
   (
       const int gsize,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int **parr,
       int *nparr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Group_pauto_d_create_i
   (
       HMPI_Group* gid,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count
   );

   /*-----------------------------------------------------*/

   #endif

==> heteroscalapack-1.0.7-BETA.tar.gz: heteroscalapack-1.0.7-BETA/HETEROMPI/include/hmpi_internal_funcs.h <==

/*************************************************************************
*                                                                       *
*                 HMPI Programming Environment                          *
*                 ============================                          *
*                                                                       *
*  Copyright (c) 2002          Department of Computer Science,          *
*                              University College Dublin.               *
*                                                                       *
*  All rights reserved. We assume no responsibility for the use         *
*  or reliability of our software.                                      *
*                                                                       *
*************************************************************************/

   /************************************************/
   /* hmpi - Internal helper functions of the      */
   /*        the HeteroMPI library                 */
   /*                                              */
   /* Revision history                             */
   /* 04-10-2007  --      Adding optimal algorithm */
   /*                     parameters to the Network*/
   /************************************************/

   #ifndef __HMPI_INTERNAL_FUNCS_HH
   #define __HMPI_INTERNAL_FUNCS_HH

   #define  HMPI_MAX_INITIAL_PROC_ARRMTS   16
   #define  HMPI_MSG_TAG                   0xff

   /*-----------------------------------------------------*/

   int
   HMPI_Get_process_arrangements_recursively_i
   (
       int d,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int gsize,
       int numcoord,
       int *coord,
       int **parr,
       int *nparr,
       int *max_nparr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Get_process_arrangements_i
   (
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int **parr,
       int *nparr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Test_size_i
   (
       int gsize,
       int numcoord,
       const int *dim
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Evaluate_model_recursively_i
   (
       int d,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int gsize,
       int numcoord,
       double *mintime,
       int *dim,
       int *optimal_dim,
       int **optimal_speeds
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Group_auto_create_i
   (
       HMPI_Group* gid,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Test_one_proc_i
   (
       int numcoord,
       const int *dim
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Group_pauto_create_i
   (
       HMPI_Group* gid,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count
   );

   /*-----------------------------------------------------*/

   int HMPI_Reorder_arrangements_i(
       int numcoord,
       int nparr,
       int *parr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Copy_arrangements_i
   (
       int numcoord,
       int *dim1,
       int *dim2
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Get_product_i
   (
       int numcoord,
       const int *dim
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Execute_heuristic_d_i
   (
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int numcoord,
       int *coord,
       int **parr,
       int *nparr,
       int *max_nparr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Get_process_arrangements_d_loop_i
   (
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int gsize,
       int numcoord,
       int *coord,
       int **parr,
       int *nparr,
       int *max_nparr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Get_process_arrangements_d_i
   (
       const int gsize,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count,
       int **parr,
       int *nparr
   );

   /*-----------------------------------------------------*/

   int
   HMPI_Group_pauto_d_create_i
   (
       HMPI_Group* gid,
       const HMPI_Model* model,
       HMPI_Heuristic_function hfunc,
       const int* model_parameters,
       int model_param_count
   );

   /*-----------------------------------------------------*/

   #endif
